# This file is managed by CFEngine
# If cf-execd is executable and if no process matching cf-execd can be found then restart cf-execd
* * * * * root [ -x {{{vars.sys.cf_execd}}} ] && if ! {{{vars.paths.pgrep}}} cf-execd > /dev/null; then {{{vars.sys.cf_execd}}}; fi
