[Unit]
Description=CFEngine Enterprise Hub Report Collector
PartOf=cfengine3.service
ConditionPathExists={{{vars.sys.bindir}}}/cf-hub
After=syslog.target
After=network.target
After=cf-redis-server.service
Requires=cf-redis-server.service
BindsTo=cf-redis-server.service

[Service]
Type=simple
ExecStart={{{vars.sys.bindir}}}/cf-hub -F --verbose
Restart=always
RestartSec=10

[Install]
WantedBy=multi-user.target
WantedBy=cfengine3.service
WantedBy=cf-redis-server.service
